* Preparation of Inhambane data sets

cd G:\data\statadata\dm\moz

* PART 1 household data set

use inh_base_hh_clean

* import the core variables for each cluster from separate file
* make sure that the file containing the core cluster data (cluster_core.dta) is in the same directory as indicated above

drop locality

merge m:1 clus using cluster_core
keep if _merge==3
drop _merge
order loc vil, after(clus)
label var locality "admin unit"
label var vil "village"
label var ddate "date of campaign distribution"

* create unique household ID from cluster and household number

gen hhid=(clus*1000)+house
label var hhid "household ID"
order hhid, after (house)

* create a date variable from the string datetime variable

gen date=date(datetime, "DMYhms")
replace date=date(datetime, "DMYhm") if date==.
format date %tdMonth_dd,_CCYY
label var date "date of interview"
order date ddate, after(datetime)

* there are some dates from August (wrong date in Tablet PC)
replace date=d(17/11/2015) if date==d(13/08/2015)
replace date=d(18/11/2015) if date==d(14/08/2015)
replace date=d(19/11/2015) if date==d(15/08/2015)
replace date=d(20/11/2015) if date==d(16/08/2015)

* create variable of time since distribution
* by subtracting ddate from date and converting into months 

gen tdistr=(date-ddate)/30.5
label var tdistr "time since distribution in months"
format tdistr %4.1f
order tdistr, after(ddate)

* create educational variable

clonevar edu=level
replace edu=0 if edu==. & school!=1 & hhstat==1
replace edu=1 if readwrite==1 & edu==0
label define edu 0 "non-literate" 1 primary 2 secondary 3 tertiary 9 DNK, modify
label val edu edu
label var edu "educational level of head HH"

gen edugr=edu
recode edugr 9=1 3=2
label var edugr "grouped education of head"
label define edugr 0 "non-literate" 1 primary 2 "secondary or better", modify
label val edugr edugr

* create grouped variables of house condition and assets

gen watergr=water
recode watergr 2=1 3/4=2 5/6=3
label define watergr 1 "unsafe: surface or rain pipe" 2 "safe: well or borehole" 3 "safe: tap", modify
label var watergr "grouped water source"
label val watergr watergr

gen latrgr=latrine
recode latrgr 3=2 4/5=3 6/7=4
label define latrgr 1 "none/bush" 2 pit 3 VIP 4 flush, modify
label val latrgr latrgr
label var latrgr "grouped type of latrine"

gen anytrans=bici==1 | moto==1 | car==1 | animaltr==1 | boat==1 if hhstat==1
label var anytrans "HH has any means of transport"
label val anytrans yesno

gen anyanimal=chic>0 | duck>0 | goat>0 | pig>0 | cow>0 | donkey>0 | othanimal>0 if hhstat==1
label var anyanimal "HH has any livestock"
label val anyanimal yesno

gen ecogr=0 if anyanimal==0 & land==0
replace ecogr=1 if anyanimal==1 & land==0
replace ecogr=2 if anyanimal==0 & land==1
replace ecogr=3 if anyanimal==1 & land==1
label var ecogr "HH economic assests"
label define ecogr 0 "no livestock, no land" 1 "livestock, no land" /*
*/ 2 "no livestock, land" 3 "both livestock and land", modify
label val ecogr ecogr

save inh_base_hh_final, replace

******************************************************************************

* PART 2 prepare member file and import needed variables into household file

use inh_base_ind_clean

* separate cluster, household and person line number form the unique person ID

format persid %10.0f

gen temp=int(persid/10) if persid<4000000
replace temp=int(persid/100) if persid>4000000

gen line=persid-(temp*10) if persid<4000000
replace line=persid-(temp*100) if persid>4000000
label var line "person's line number"

gen clus=int(temp/1000)
label var clus "cluster number"

gen prov=int(clus/100)
label var prov "province"
label define prov 1 Inhambane 2 Tete 3 Nampula, modify
label val prov prov

gen house=temp-(clus*1000)
label var house "house number"

gen hhid=(clus*1000)+house
label var hhid "household ID"

drop temp

order prov clus house hhid line, before(persid)

* create age groups and create and extract variables for household file

gen u5=age<5
label var u5 "is under 5"

egen agegr=cut(age), at(0,5,15,25,50,102) label
label var agegr "age groups in years"

gen hhage=age if rel==1 & age<999
label var hhage "age of head of HH"

gen hhsex=sex if rel==1 
label var hhsex "gender of head of HH"
label val hhsex sex

* set for survey analysis

svyset clus, strata(prov)

save inh_base_ind_final, replace

* collapse variables and export to household file

collapse (sum) live u5 (max) hhage hhsex, by(hhid)

rename live person
label var person "number of de-jure HH members"

rename u5 numu5
label var numu5 "number of U5 in HH"

label var hhage "age of head of HH"
label define sex 1 male 2 female, modify
label val hhsex sex

label var hhsex "gender of head of HH"

save inh_ind_hh_1, replace

use inh_base_hh_final

merge 1:1 hhid using inh_ind_hh_1
drop if _merge==2
drop _merge

replace numu5=0 if numu5==.
gen anyu5= numu5>0
label var anyu5 "HH has any U5"
label val anyu5 yesno
order anyu5, after(numu5)

egen persgr=cut(person), at(1,4,7,40) label
label var persgr "grouped household size"
order persgr, after(person)

save, replace

******************************************************************************

* PART 3 further preparations in household file

* prepare wealth index and tertiles

* create dichotomous variables for the categorical ones
tab edugr, gen(edugr)
tab roof, gen(roof)
tab wall, gen(wall)
tab floor, gen(floor)
tab cook, gen(cook)
tab watergr, gen(watergr)
tab latrgr, gen(latrgr)

* run principle component analysis
set more off
pca edugr1 edugr2 edugr3 roof1 roof2 roof3 wall1 wall2 wall3 wall4 floor1 floor2/*
*/ floor3 floor4 floor5 cook1 cook2 cook3 cook4 watergr1 watergr2 watergr3 latrgr1 latrgr2/*
*/ latrgr3 latrgr4 radio tv fridge fan iron mobile smart computer bici moto car/*
*/ animaltr boat chick duck goat pig cow donkey land

* use first component as wealth score
predict wealth
label var wealth "wealth score from pca"

* create quintiles
egen ses=cut(wealth), group(3)
replace ses=ses+1
label define ses 1 "lowest" 2 "middle" 3 "highest", modify
label val ses ses
label var ses "wealth tertiles"

*drop the dichotomus varaibles
drop edugr1 edugr2 edugr3 roof1 roof2 roof3 wall1 wall2 wall3 wall4 floor1 floor2/*
*/ floor3 floor4 floor5 cook1 cook2 cook3 cook4 watergr1 watergr2 watergr3 latrgr1 latrgr2/*
*/ latrgr3 latrgr4

* BCC exposure and net use and care attitudes

gen nummes= meschw + mesradio + messong + mesdrama + meshw + meslead + mestown /*
*/ + messhop + mesfam + mesfaith + mesnews
replace nummes=0 if anymes==0
label var nummes "# of info sources mentioned"

gen nummesgr=nummes
recode nummesgr 5/max=4
label var nummesgr "grouped # of info sources"
label define nummesgr 4 "4 or more", modify
label val nummesgr nummesgr

gen mesmedia=mesradio==1 | messong==1 | mesnews==1 if hhstat==1
label var mesmedia "from radio or print media"
label val mesmedia yesno

gen mesipc=meschw==1 | mesdrama==1 | meshw==1 | meslead==1 | mestown==1 /*
*/ | messhop==1 | mesfam==1 if hhstat==1
label var mesipc "from IPC"

gen mesgr=0 if hhstat==1
replace mesgr=1 if mesmedia==1 & mesipc==0
replace mesgr=2 if mesmedia==1 & mesipc==1
replace mesgr=3 if mesmedia==0 & mesipc==1
label var mesgr "combination of info sources"
label define mesgr 0 None 1 "media only" 2 both 3 "IPC only", modify
label val mesgr mesgr

gen rcuse2=rcuse==1 | rcevery==1 if hhstat==1
label var rcuse2 "recalls use or use every night"
label val rcuse2 yesno

gen numrc=rcuse + rccare + rchang + rcevery + rcprev + rcrep
label var numrc "# of messages recalled"
replace numrc=0 if anymes==0 & numrc==.

* knowledge of net care and washing

gen numdo=dochild + dopest + dotie + dohandle + donofood + dofire + dogentle /*
*/ + dowash + doinsp + doearly
label var numdo "# of positive actions mentioned"

gen numdogr=numdo
recode numdogr 5/max=4
label define numdogr 4 "4 or more", modify
label val numdogr numdogr
label var numdogr "grouped positive actions"

gen numw=wgentle + wbasin + wsoap + wdirty + wfreq + wstream
label var numw "# of correct washing approach mentioned"

gen numwgr=numw
recode numwgr 5/max=4
label define numwgr 4 "4 or more", modify
label val numwgr numwgr
label var numwgr "grouped wash knowledge"

* recode lickert score variables and creade net and C&R attitude scores

recode ls01 1=2 2=1 3=-1 4=-2
label define lsscore 2 "Definitely could" 1 "Probably could" -1 /*
*/ "Probably could not" -2 "Definitely could not", modify
label val ls01 lsscore

recode ls02 1=2 2=1 3=-1 4=-2
label val ls02 lsscore

recode ls03 1=2 2=1 3=-1 4=-2
label val ls03 lsscore

recode ls04 1=2 2=1 3=-1 4=-2
label val ls04 lsscore

recode ls05 1=2 2=1 3=-1 4=-2
label val ls05 lsscore

recode ls06 1=2 2=1 3=-1 4=-2
label val ls06 lsscore

gen nattscore=(ls01+ls02+ls03+ls04+ls05+ls06)/6
label var nattscore "net attitude score"

egen nattgr=cut(nattscore), at(-2,0.01,1.01, 2.01) label 
label variable nattgr "grouped net attitude score"
label define nattgr 0 "-2 to 0" 1 "0.01 to 1.0" 2 "1.01 to 2.0", modify
label values nattgr nattgr

gen nattpos=nattscore>0 if nattscore!=.
label var nattpos "positive net attitude (>0)"

recode ls07 1=2 2=1 3=-1 4=-2
label define lsscore2 2 "Strongly agree" 1 "Somewhat agree" -1 "Somewhat disagree"/*
*/ -2 "Strongly disagree", modify
label val ls07 lsscore2

recode ls08 1=2 2=1 3=-1 4=-2
label val ls08 lsscore2

recode ls09 1=2 2=1 3=-1 4=-2
label val ls09 lsscore2

recode ls10 1=2 2=1 3=-1 4=-2
label val ls10 lsscore2

recode ls11 1=2 2=1 3=-1 4=-2
label val ls11 lsscore2

recode ls12 1=2 2=1 3=-1 4=-2
label val ls12 lsscore2

recode ls13 1=2 2=1 3=-1 4=-2
label val ls13 lsscore2

recode ls14 1=2 2=1 3=-1 4=-2
label val ls14 lsscore2

* note: because ls09 and ls12 are negative, they are inversed before added
* note: ls11 is omitted

gen crattscore=(ls07+ls09+(ls09*-1)+ls10+(ls12*-1)+ls13 + ls14)/7
label var crattscore "care & repair attitude score"

egen crattgr=cut(crattscore), at(-2,0.01,1.01, 2.01) label 
label variable crattgr "grouped c&r attitude score"
label define crattgr 0 "-2 to 0" 1 "0.01 to 1.0" 2 "1.01 to 2.0", modify
label values crattgr crattgr

gen crattpos=crattscore>0 if crattscore!=.
label var crattpos "positive c&r attitude (>0)"

* set for survey analysis

svyset clus, strata(prov)

save, replace

***************************************************************************

* PART 4 extract data on lost campaign nets

keep hhid prov netage* netstat* ause* reas* reasoth*

reshape long netage netstat ause reas reasoth, i(hhid) j(net)
drop if netstat==.

label var net "net number"

label var netage "Q79 months until loss"

label var netstat "Q80 what happened to net"

label var ause "Q81 alternative use"

label var reas "Q82 reason for not keeping net"

label var reasoth "Q82 other reasons"

* recode "other" in netstat where appropriate from info in "reasoth"
replace netstat=5 if netstat==8 & reasoth!=""

* create attrition variables

gen attr=1 if netstat==1 | (netstat>2 & netstat<6)
replace attr=2 if netstat==2 | netstat==6 | netstat==7
replace attr=3 if netstat==8 | netstat==9
label var attr "attrition"
label define attr 1 "given away to others" 2 "discarded or used otherwise" 3 "unknown", modify
label val attr attr

gen given=attr==1
label var given "given away"
label define yesno 0 no 1 yes 9 DNK, modify
label val given yesno

gen discard=attr==2
label var discard "discarded or used otherwise"
label val discard yesno

save inh_base_lostc, replace

****************************************************************************

* PART 5 prepare campaign net file

use inh_base_cnet_clean 

* extract hhid from netid

gen hhid=int(netid/10)
label var hhid "household ID"
order hhid, after(netid)

save inh_base_cnet_final, replace

* import variables from household file

use inh_base_hh_final

keep hhid clus prov date tdistr ses edugr persgr anyu5 numu5 mesgr numdogr numwgr crattgr nattgr

save inh_hh_net_1, replace

use inh_base_cnet_final

merge m:1 hhid using inh_hh_net_1
* all records match
keep if _merge==3
drop _merge
order clus prov, after(hhid)

* set for survey analysis

svyset clus, strata(prov)

save, replace

* create additional variables

gen hang=loc==1 | loc==2
label var hang "net is hanging"

gen splacegr=splace
recode splacegr 2=1 3=2 4/6=3 7=4
label var splacegr "grouped type of sleeping place"
label define splacegr 1 bed 2 mattress 3 "mat or ground" 4 "not used", modify
label val splacegr splacegr

gen usegr=7 if uselast==1
replace usegr=1 if (useinf==1 | useych==1) & useoch==0 & useadol==0 & useadult==0
replace usegr=2 if (useinf==1 | useych==1) & useoch==1 & useadol==0 & useadult==0 & usegr==7
replace usegr=3 if useinf==0 & useych==0 & useoch==1 & useadol==0 & useadult==0 & usegr==7
replace usegr=4 if (useinf==1 | useych==1) & useoch==0 & (useadol==1 | useadult==1) & usegr==7
replace usegr=5 if (useinf==1 | useych==1) & useoch==1 & (useadol==1 | useadult==1) & usegr==7
replace usegr=6 if useinf==0 & useych==0 & useoch==0 & (useadol==1 | useadult==1) & usegr==7
label var usegr "grouped net users"
label define usegr 1 "U5 only" 2 "U5 + older child" 3 " child only" 4 "U5+adult/adol" 5 "U5+ch+adult" 6 "adol/adult only" 7 "child + adol/adult", modify
label val usegr usegr

gen usegr2=usegr
recode usegr2 2/3=1 4/5=2 7=2 6=3
label var usegr2 "grouped net users"
label define usegr2 1 "children only" 2 "children + adol/adult" 3 "adol/adult only", modify
label val usegr2 usegr2

gen nmech=tear1 +tear2 + burn + rats + seam + mecoth if everh==1
label var nmech "number of hole mechanisms reported"

gen tear=tear1==1 | tear2==1 if everh==1
label var tear "any tear mechanism"

* hole index

gen code98=size1>90 | size2>90 | size3>90 | size4>90 
label var code98 "is coded 98"

replace size4=10 if code98==1
replace size1=0 if code98==1
replace size2=0 if code98==1
replace size3=0 if code98==1

gen anyhole=size1>0 | size2>0 | size3>0 | size4>0 
label var anyhole "has any hole"

* prepare hole index based on WHOPES weights 

gen phiw=size1+(size2*23)+(size3*196)+(size4*578) 
label var phiw "proportionate hole index whopes weights"

gen phiwgr=phiw
recode phiwgr 0/64=1 65/300=2 301/642=3 643/max=4
label define phiwgr 1 "0-64" 2 "65-300" 3 "301-642" 4 "643+", modify
label val phiwgr phiwgr
label var phiwgr "grouped pHIw"    

gen good=phiwgr==1 
label var good "is in excellent condition"

gen torn=phiwgr==4 
label var torn "is too torn"

gen damage=phiwgr==2 | phiwgr==3
label var damage "is damaged but not too torn"

gen serv=phiwgr<4 
label var serv "is serviceable (not too torn)"

* repairs and modifications

gen anyrep=repair>0 | partrep>0 if anyhole==1
label var anyrep "any sign of repair"

gen anyrepf=repair>0 if anyhole==1
label var anyrepf "any full hole repair"

gen anyrepp=partrep>0 if anyhole==1
label var anyrepp "any partial hole repair"

save, replace

* export variables to household file

egen ncohort=sum(confc), by(hhid)

egen nhole=sum(anyhole), by(hhid)

egen ngood=sum(good), by(hhid)

egen nserv=sum(serv), by(hhid)

egen ntorn=sum(torn), by(hhid)

egen nrep=sum(anyrep), by(hhid)

collapse (mean) ncohort nhole ngood nserv ntorn nrep, by(hhid)

label var ncohort "# of cohort nets in HH"
label var nhole "# of cohort nets with any hole in HH"
label var ngood "# of cohort nets in good condition in HH"
label var nserv "# of cohort nets serviceable in HH"
label var ntorn "# of cohort nets torn in HH"
label var nrep "# of cohort nets with repairs in HH"

save inh_cnet_hh_1, replace

use inh_base_hh_final

merge 1:1 hhid using inh_cnet_hh_1
drop _merge

replace ncohort=0 if ncohort==.

gen anycohort=ncohort>0
label var anycohort "HH has any cohort nets"
label val anycohort yesno

gen anyhole=nhole>0 if anycohort==1
label var anyhole "HH has any cohort net with holes"
label val anyhole yesno

gen anygood=ngood>0 if anycohort==1
label var anygood "HH has any cohort net in good condition"
label val anygood yesno

gen anyserv=nserv>0 if anycohort==1
label var anyserv "HH has any cohort net serviceable"
label val anyserv yesno

gen anytorn=ntorn>0 if anycohort==1
label var anytorn "HH has any cohort net torn"
label val anytorn yesno

gen anyrep=nrep>0 if anycohort==1
label var anyrep "HH has any cohort net with repairs"
label val anyrep yesno

save, replace

******************************************************************************

* PART 6 prepare non-campaign net file

use inh_base_ncnet_clean

* create hhid from clus and house

gen hhid=(clus*1000)+house
label var hhid "household ID"
order hhid, before(clus)

save inh_base_ncnet_final, replace

* import variables from household file

merge m:1 hhid using inh_hh_net_1
* all ncnets match
keep if _merge==3
drop _merge
order prov, after(hhid)

* set for survey analysis

svyset clus, strata(prov)

save, replace

* create additional variables

gen llin=brand <7 | (brand>10 & brand<15)
label var llin "net is LLIN"
label val llin yesno

gen itn=llin
replace itn=1 if dipmgr==1 & llin==0
label var itn "net is ITN"
label val itn yesno

gen ntype=1 if llin==1
replace ntype=2 if itn==1 & llin==0
replace ntype=3 if (brand>6 & brand<11) & ntype==.
label define ntype 1 LLIN 2 "conv ITN" 3 untreated, modify
label val ntype ntype
label var ntype "type of net"	

replace nagey=0 if nagey==.
gen netage=nagey*12 if nagey<98
replace netage=netage+(nagem) if nagey==0 & nagem<98
replace netage=. if netage==0 & nagem==.
format netage %9.0f
label var netage "age of net in months"

egen nagegr=cut(netage), at(0,6,12,24,36,48,200) 
label var nagegr "grouped net age in months"
label define nagegr 48 "48+", modify
label val nagegr nagegr

gen cnet=llin==1 & source==1 & netage<=(tdistr+1)
label var cnet "net from last campaign"
label val cnet yesno

gen ncnet=cnet==0
label var ncnet "non-campaign net"
label val ncnet yesno

gen pub_ncnet=(source<4 | source==12) & ncnet==1
label var pub_ncnet "non-campaign net from public sector"
label val pub_ncnet yesno

gen priv=source>6 & source<12
label var priv "net from private sector"
label val priv yesno

gen sourcegr=3
replace sourcegr=1 if pub==1
replace sourcegr=2 if priv==1
label define sourcegr 1 public 2 private 3 other, modify
label val sourcegr sourcegr
label var sourcegr "grouped sources of net"

gen osource= sourcegr==3
label var osource "net from family/friends, NGO etc"
label val osource yesno

gen hang=loc==1 | loc==2
label var hang "net is hanging"

gen usegr=7 if uselast==1
replace usegr=1 if (useinf==1 | useych==1) & useoch==0 & useadol==0 & useadult==0
replace usegr=2 if (useinf==1 | useych==1) & useoch==1 & useadol==0 & useadult==0 & usegr==7
replace usegr=3 if useinf==0 & useych==0 & useoch==1 & useadol==0 & useadult==0 & usegr==7
replace usegr=4 if (useinf==1 | useych==1) & useoch==0 & (useadol==1 | useadult==1) & usegr==7
replace usegr=5 if (useinf==1 | useych==1) & useoch==1 & (useadol==1 | useadult==1) & usegr==7
replace usegr=6 if useinf==0 & useych==0 & useoch==0 & (useadol==1 | useadult==1) & usegr==7
label var usegr "grouped net users"
label define usegr 1 "U5 only" 2 "U5 + child" 3 " child only" 4 "U5+adult/adol" 5 "U5+ch+adult" 6 "adol/adult only" 7 "child + adult", modify
label val usegr usegr

gen usegr2=usegr
recode usegr2 2/3=1 4/5=2 7=2 6=3
label var usegr2 "grouped net users"
label define usegr2 1 "children only" 2 "children + adol/adult" 3 "adol/adult only", modify
label val usegr2 usegr2

save, replace

* export variables to household file

egen numcnet=sum(cnet), by(hhid)

egen nncnet=sum(ncnet), by(hhid)

egen npub_n=sum(pub_n), by(hhid)

egen npriv=sum(priv), by(hhid)

egen nosource=sum(osource), by(hhid)

egen nllin_ncnet=sum(llin), by(hhid)

egen nitn_ncnet=sum(itn), by(hhid)

collapse (mean) numcnet nncnet npub_n npriv nosource nllin_n nitn_n, by(hhid)

label var numcnet "# of non-cohort campaign nets in HH"
label var nncnet "# of non-campaign nets in HH"
label var npub_n "# of non-campaign nets from public in HH"
label var npriv "# of nets from private in HH"
label var nosource "# of nets from family/friends, NGO etc"
label var nllin_n "# of non-cohort LLIN on HH"
label var nitn_n "# of non-cohort ITN in HH"

save inh_ncnet_hh_1, replace

use inh_base_hh_final

merge 1:1 hhid using inh_ncnet_hh_1
drop _merge

replace npriv=0 if npriv==.
gen anypriv=npriv>0
label var anypriv "HH has any nets from private"
label val anypriv yesno

replace numcnet=0 if numcnet==.
gen anycnet=numcnet>0
replace anycnet=1 if anycohort==1 & anycnet==0
label var anycnet "HH has any net from campaign"
label val anycnet yesno

replace nncnet=0 if nncnet==.
gen anyncnet=nncnet>0
label var anyncnet "HH has any non-campaign nets"
label val anyncnet yesno

replace npub_n=0 if npub_n==.
gen anypub_ncnet=npub_n>0
label var anypub_n "HH has any non-campaign nets from public"

replace nosource=0 if nosource==.
gen anyosource=nosource>0
label var anyosource "HH has nets from family/friends, NGO etc"
label val anyosource yesno

gen many2=ncohort+numcnet+nncnet
label var many2 "# of nets owned from net files"

replace nllin_ncnet=0 if nllin_ncnet==.
gen nllin=ncohort+nllin_ncnet
label var nllin "# of LLIN in HH"

replace nitn_ncnet=0 if nitn_ncnet==.
gen nitn=ncohort+nitn_ncnet
label var nitn "# of ITN in household"

* there are 9 households without any campaign nets and these are dropped

drop if anycnet==0

save, replace

* create variables for household net ownership and supply situation

gen netpers=many2/person if person!=.
label var netpers "nets per person in HH"
gen p2net=netpers>=0.5
label var p2net "hh has 1net/2people"

gen itnpers=nitn/person if person!=.
label var itnpers "ITN per person in HH"
gen p2itn=itnpers>=0.5
label var p2itn "hh has 1ITN/2people"

gen suplpitn=0 if itnpers==0
replace suplp=. if itnpers==.
replace suplp=1 if itnpers>0 & itnpers<0.303030303
replace suplp=2 if itnpers>=0.303 & itnpers<0.5
replace suplp=3 if itnpers>=0.5 & itnpers<1.0
replace suplp=4 if itnpers>=1.0 & itnpers<6

label var suplpitn "HH supply situation with ITN"
label define suplp 0 "no ITN" 1 "< 1ITN/ 3 persons" 2 "1 ITN/ 3 persons" 3 "1 ITN/ 2 persons" 4 "1 ITN/ person or more", modify
label val suplpitn suplp

gen suplp2=suplpitn
recode suplp2 2=1 3/4=2
label var suplp2 "HH supply with ITN"
label define suplp2 0 none 1 "not enough" 2 "enough", modify
label val suplp2 suplp2

save, replace

*****************************************************************************

* PART 7 transfer variables to household member (individuals) file and calculate access

keep hhid nitn p2itn ses

save inh_hh_ind_1, replace

use inh_base_ind_final

merge m:1 hhid using inh_hh_ind_1
* all match
keep if _merge==3
drop _merge

* calculate access indicator 

gen potuse=nitn*2
label var potuse "potential ITN users in hh"

save, replace

keep if stay==1
bysort hhid: gen access=_n<=potuse 
label var access "has access to ITN"

keep access persid
save access, replace

use inh_base_ind_final

merge 1:1 persid using access
drop _merge

save, replace
